Face Detection in Video Capture {#tutorial_js_face_detection_camera}
==================================

Goal
----

-   learn how to detect faces in video capture.

@note  If you don't know how to capture video from camera, please review @ref tutorial_js_video_display.

\htmlonly
<iframe src="../../js_face_detection_camera.html" width="100%"
        onload="this.style.height=this.contentDocument.body.scrollHeight +'px';">
</iframe>
\endhtmlonly